Enum Event
#[non_exhaustive]pub enum Event<'a> {
Succeeded,
Failed,
Cancelled,
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Succeeded
configuration changes succeeded
Sent after the compositor has successfully applied the changes or tested them.
Upon receiving this event, the client should destroy this object.
If the current configuration has changed, events to describe the changes will be sent followed by a wlr_output_manager.done event.
Failed
configuration changes failed
Sent if the compositor rejects the changes or failed to apply them. The compositor should revert any changes made by the apply request that triggered this event.
Upon receiving this event, the client should destroy this object.
Cancelled
configuration has been cancelled
Sent if the compositor cancels the configuration because the state of an output changed and the client has outdated information (e.g. after an output has been hotplugged).
The client can create a new configuration with a newer serial and try again.
Upon receiving this event, the client should destroy this object.
Implementations