#[non_exhaustive]
pub enum Request { EnableHead { id: New<ZwlrOutputConfigurationHeadV1>, head: ZwlrOutputHeadV1, }, DisableHead { head: ZwlrOutputHeadV1, }, Apply, Test, Destroy, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


EnableHead

enable and configure a head

Enable a head. This request creates a head configuration object that can be used to change the head’s properties.

Fields

id: New<ZwlrOutputConfigurationHeadV1>

a new object to configure the head

head: ZwlrOutputHeadV1

the head to be enabled



DisableHead

disable a head

Disable a head.

Fields

head: ZwlrOutputHeadV1

the head to be disabled



Apply

apply the configuration

Apply the new output configuration.

In case the configuration is successfully applied, there is no guarantee that the new output state matches completely the requested configuration. For instance, a compositor might round the scale if it doesn’t support fractional scaling.

After this request has been sent, the compositor must respond with an succeeded, failed or cancelled event. Sending a request that isn’t the destructor is a protocol error.



Test

test the configuration

Test the new output configuration. The configuration won’t be applied, but will only be validated.

Even if the compositor succeeds to test a configuration, applying it may fail.

After this request has been sent, the compositor must respond with an succeeded, failed or cancelled event. Sending a request that isn’t the destructor is a protocol error.



Destroy

destroy the output configuration

Using this request a client can tell the compositor that it is not going to use the configuration object anymore. Any changes to the outputs that have not been applied will be discarded.

This request also destroys wlr_output_configuration_head objects created via this object.

This is a destructor, once received this object cannot be used any longer.

Implementations



impl Request

pub fn opcode(&self) -> u16

Get the opcode number of this message