Struct ZwlrOutputConfigurationV1
pub struct ZwlrOutputConfigurationV1 { /* private fields */ }wayland and Linux only.Expand description
output configuration
This object is used by the client to describe a full output configuration.
First, the client needs to setup the output configuration. Each head can be either enabled (and configured) or disabled. It is a protocol error to send two enable_head or disable_head requests with the same head. It is a protocol error to omit a head in a configuration.
Then, the client can apply or test the configuration. The compositor will then reply with a succeeded, failed or cancelled event. Finally the client should destroy the configuration object.
See also the Request enum for this interface.
Implementations
impl ZwlrOutputConfigurationV1
impl ZwlrOutputConfigurationV1
pub fn succeeded(&self)
pub fn succeeded(&self)
configuration changes succeeded
Sent after the compositor has successfully applied the changes or tested them.
Upon receiving this event, the client should destroy this object.
If the current configuration has changed, events to describe the changes will be sent followed by a wlr_output_manager.done event.
pub fn failed(&self)
pub fn failed(&self)
configuration changes failed
Sent if the compositor rejects the changes or failed to apply them. The compositor should revert any changes made by the apply request that triggered this event.
Upon receiving this event, the client should destroy this object.
pub fn cancelled(&self)
pub fn cancelled(&self)
configuration has been cancelled
Sent if the compositor cancels the configuration because the state of an output changed and the client has outdated information (e.g. after an output has been hotplugged).
The client can create a new configuration with a newer serial and try again.
Upon receiving this event, the client should destroy this object.